# CONP Consent Guide (v1.0.4)

**Unless otherwise noted, this work is licensed under [<u>Attribution
4.0
International</u>](http://creativecommons.org/licenses/by/4.0/?ref=chooser-v1)**

This consent guide is the product of extended discussions and careful
drafting that considers both
[<u>Canadian</u>](https://ethics.gc.ca/eng/policy-politique_tcps2-eptc2_2018.html)
and
[<u>international</u>](https://cioms.ch/publications/product/international-ethical-guidelines-for-health-related-research-involving-humans/)
ethical frameworks and research practice. It provides general guidance
to Canadian neuroscience researchers who wish to share de-identified
data in an unrestricted manner with the scientific community and the
public at large. The guide is a model for Canadian open-access
neuroscience initiatives to adopt in developing their governance
standards and it also describes the minimum permissions required for
researchers to submit data to the Canadian Open Neuroscience Platform
(CONP) Portal’s Community Server (see below).

CONP Portal users can presently choose among different methods of
hosting their data, including third-party storage provided by the OSF or
Zenodo, or storage native to the CONP’s technical infrastructure, known
as the ‘Community Server’. Greater flexibility still in data hosting
location is available through the combined use of the DataLad
distributed data-management system and the GitHub open software
repository to host the dataset metadata.

These distinctions in data storage location have stewardship
implications:

1. For **data that are accessible through the Portal but stored on
    non-CONP servers**, it is sufficient for contributors to abide by
    their local legal and biomedical research ethics requirements and to
    respect the data stewardship regulations of the selected host
    repository. In this case, adherence to **the CONP data stewardship
    guidance is recommended but not required**.

2.  However, for **data natively hosted on its Community Sever** and for
    which it therefore takes on the role of primary data steward, **the
    CONP requires adherence to its data governance standards**, which
    are described below.

In adapting this consent guide for your own research needs, we encourage
you to mention to your research ethics board that your consent materials
are modeled after those created by the [<u>CONP Ethics and Governance
Committee</u>](https://conp.ca/ethics-data-governance/), whose members
include internationally recognized experts in research ethics,
neuroethics, data governance, and law: Trudo Lemmens (Chair), Alexander
Bernier (Manager), Ann Cavoukian, John Clarkson, Jason Karamchandani,
Roland Nadler, Dylan Roskams-Edris, and Walter Stewart. Further feedback
was graciously provided from members of the CONP community, in
particular Patrick Bermudez, Marcel Farrés Franch, Jessica Royer, Robert
Zatorre, and past Committee Members Bartha Maria Knoppers, Lindsay Green
Noble, and Judy Illes.

This document provides general, ‘best-practice’ guidance for open
data-sharing which must be adhered to in the specific case of
data-sharing through the CONP’s Community Sever. The CONP’s Community
Server accepts datasets in two situations:

1.  Participants have prospectively consented to the sharing of their
    de-identified data via an open data-sharing repository.

2.  Participants have not consented to the sharing of their data on the
    CONP Portal, but the consent given meets the core consent elements
    for retrospective consent.

Each of these situations are be explained below.

## Part 1: Core consent elements (prospective consent)

Researchers and/or clinicians should prospectively seek consent to the
open sharing of de-identified datasets. Depending on the circumstances,
consent should be sought from either the prospective participant
directly (first-person consent) or from their legally authorized
representative (substitute consent). First-person consent is appropriate
for adults with legal capacity. Substitute consent is for situations
where the prospective participant lacks legal capacity either due to age
(i.e., minors) or due to an inability to understand the nature and
consequences of research participation (i.e., limited cognitive
ability). In these circumstances, the prospective participant should be
involved in the consent process to the fullest extent of their ability
to do so.

In addition to the required consent elements common to research with
human participants, prospective consent forms should include the
following core elements to enable broad, open sharing via the CONP
Portal:

### Table 1: Core consent elements for contributing datasets to the CONP Portal.

<table>
<colgroup>
<col style="width: 32%" />
<col style="width: 67%" />
</colgroup>
<thead>
<tr class="header">
<th></th>
<th><strong>To contribute datasets to the CONP Portal Community Sever,
participants should consent to:</strong></th>
</tr>
</thead>
<tbody>
<tr class="odd">
<td><strong>Data generation</strong></td>
<td>Generation of participant data for research purposes</td>
</tr>
<tr class="even">
<td><strong>De-identification (coding, anonymization, and synthetic data
generation)</strong></td>
<td><p>De-identification of their data, which may consist of a
combination of the following processes:</p>
<p>Coding – the removal of direct identifiers (e.g., name; health
insurance number) and replaced with a code whose key is kept in a secure
location</p>
<p>Anonymization – the permanent removal of direct identifiers without
the conservation of any keys</p>
<p>Data synthesis – the creation of a dataset with similar statistical
properties as the original dataset but without a one-to-one match for
every variable</p></td>
</tr>
<tr class="odd">
<td><strong>CONP Portal Community Sever</strong></td>
<td>Sharing of de-identified data via the CONP Portal Community Sever,
an open-access platform that researchers the world over may access</td>
</tr>
<tr class="even">
<td><strong>Commercial use</strong></td>
<td>Use of de-identified data for commercial purposes</td>
</tr>
<tr class="odd">
<td><strong>Data withdrawal</strong></td>
<td>Not possible to withdraw data that has already been shared</td>
</tr>
<tr class="even">
<td><strong>Re-identification</strong></td>
<td>Low risk that the participant could be re-identified in the
future</td>
</tr>
</tbody>
</table>

If any of the elements in **Table 1** have not been included in the
informed consent documents, datasets should not be uploaded to the CONP
Portal Community Sever (though it might still be possible to share them
through the CONP Portal by one of its other data-storage methods). In
such circumstances, we recommend you examine the ‘retrospective filter’
below. If doubts remain or you have questions about the suitability of
these consent elements for your research, please consult with your local
research ethics board.

<u>Note</u>: Researchers who want to repurpose the above guidance to
establish the terms of data deposit for a different open science
platform should replace the phrase “CONP Portal” in the above template
with the name of the concerned open science platform.

We recognize that some research projects may choose to have a tiered
consent model, whereby participants consent to only certain data types
being publicly shared via the CONP Portal or other open data repository.
In such circumstances, the essential consent elements are only required
with respect to those data types. It is the researcher’s responsibility
to ensure that data segmentation is appropriately managed so that only
those data types for which consent to open data sharing has been given
are shared.

See [**Annex 1**](#annex1) below for suggested clauses to include in the
informed consent documentation.

## Part 2: Retrospective consent filter

Use the filter below to determine if the consent already obtained from
participants will permit you to include the data on the CONP Portal
Community Server.

### Step 1: Answer the following questions.

| Have your participants consented to:                    | Yes | No  |
|---------------------------------------------------------|-----|-----|
| Deposit of de-identified data in open-access databases? |     |     |
| Commercial use?                                         |     |     |

### Step 2: If all your responses in step 1 were “yes”, your data can be submitted for inclusion on the CONP Portal Community Server. If any of the responses were “no”, answer the following questions.

|                                                                                                                                                                                              | Yes | No  |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----|-----|
| Have your participants consented to be re-contacted?                                                                                                                                         |     |     |
| Is it feasible (i.e., not onerous to the degree of jeopardizing your research) to re-contact and consent your participants for inclusion on the CONP Portal Community Sever Community Sever? |     |     |

### Step 3: If both answers in step 2 were “yes”, re-contact your participants and obtain their consent using the example consent clauses in Annex 1. Otherwise, answer the following question.
(Note: Only those participants who were re-contacted and gave appropriate consent can be included in the dataset included on the CONP Portal Community Sever Community Sever. If you have recontacted your participants and they have withheld consent, you are unlikely to obtain a waiver.)

|                                                                                                                                   | Yes | No  |
|-----------------------------------------------------------------------------------------------------------------------------------|-----|-----|
| Are you able to apply to your research ethics board for a waiver, i.e., an authorization to alter the initial consent parameters? |     |     |

### Step 4: If the answer in step 3 was “yes”, apply to your research ethics board for a waiver. If the answer was “no”, your data cannot be included on the CONP Portal Community Sever.

<span id="annex1" class="anchor"></span>

## Annex 1: Example consent clauses for the essential consent elements.

<table>
<colgroup>
<col style="width: 21%" />
<col style="width: 19%" />
<col style="width: 29%" />
<col style="width: 29%" />
</colgroup>
<thead>
<tr class="header">
<th colspan="4">The example consent clauses are marked with <a
href="http://creativecommons.org/publicdomain/zero/1.0?ref=chooser-v1"><u>CC0
1.0 Universal</u></a></th>
</tr>
<tr class="odd">
<th></th>
<th><strong>Essential elements</strong></th>
<th><strong>Example of consent clause language:</strong></th>
<th><strong>Alternative consent clause</strong>
[1]<strong>:</strong></th>
</tr>
</thead>
<tbody>
<tr class="odd">
<td><strong>Data generation</strong></td>
<td>The generation of participant data for research purposes</td>
<td><p>You are being asked to consent to [<em>include relevant
procedure, e.g., imaging</em>] procedure(s) that will generate data
about your [<em>include relevant data types, e.g., cognitive
performance</em>] for research purposes.</p>
<p>[<em>If questionnaires are also included...</em>]</p>
<p>You will also be asked questions about [<em>include description of
the types of questions, e.g., personal biographical information, health
status, etc.</em>]</p></td>
<td>N/A</td>
</tr>
<tr class="even">
<td><strong>De-identification (coding, anonymization, and synthetic data
generation)</strong></td>
<td>Removal of direct and indirect identifiers, the restructuring of
data, and the generation of synthetic data for open sharing</td>
<td><p>To protect your privacy and to facilitate the broadest possible,
public sharing of the data that you and other participants contribute,
your name, date of birth and other directly identifying information will
not be shared.</p>
<p>Some data, [<em>e.g., name; date of birth; occupation; etc.</em>],
will be replaced by a code.</p>
<p>Other data that we believe may allow others to determine who you are,
such as your [<em>include relevant feature, e.g., facial features</em>]
will be irreversibly changed through a family of processes called
anonymization so that you cannot be identified.</p>
<p>Other information, such as [<em>include relevant data, e.g., age
group; location</em>], will be pooled together with those of other
participants for high-level summaries.</p></td>
<td><p>Your privacy is very important to us, and we will take
appropriate measures to protect it. We will not disclose any information
about you like your name, your date of birth, your address, or your
contact information to unauthorized persons. All personal identifying
information will be replaced with a unique code.</p>
<p>Before researchers have access to your data, we will de-identify it.
This means we take out names, dates of birth [<em>include others, if
any</em>] and other personal details.</p>
<p>Your participation in this research project and any information
obtained within this research project that can identify you will remain
confidential, except as required by law [<em>circumstances in which
confidential information can be released by law should be explained to
the participant</em>].</p></td>
</tr>
<tr class="odd">
<td><strong>CONP Portal Community Sever</strong></td>
<td>Sharing of de-identified data via the CONP Portal, an open-access
platform that researchers the world over may access</td>
<td><p>After having gone through the described de-identification
process, a dataset made of your de-identified data and those of other
participants will be uploaded to [<em>specify the online platform or
give a list of potential options if known, e.g., Zenodo, LORIS,
etc.</em>]. The link to the dataset will then be included on the
Canadian Open Neuroscience Platform (CONP) Portal to be openly shared
with the scientific community.</p>
<p>As an Open Science platform, CONP aims to make scientific data as
easily accessible as possible to the scientific community while
respecting your privacy.</p>
<p>CONP is publicly available to anyone with internet access.
Researchers from around the world will use the CONP Portal to access the
de-identified data from this research study and other studies. This
maximizes the potential for this project’s research data to be used for
additional research that may lead to important scientific
discoveries.</p></td>
<td>With your consent, we will share de-identified information with
other researchers from around the world who would use it to improve
patient care or advance scientific knowledge, for clinical and/or
general research purposes. Your information will be shared with others
through open-access databases, such as the Canadian Open Neuroscience
Platform (CONP). CONP is publicly available to anyone with internet
access. General information, such as age, race, or sex, or your
de-identified [<em>specify data type, e.g., MRI images</em>] may be
shared in these types of databases.</td>
</tr>
<tr class="even">
<td><strong>Commercial use</strong></td>
<td>Use of de-identified data for commercial purposes</td>
<td>It is possible that future research conducted using datasets that
include both your de-identified data and those of others will lead to
the development of commercial products. These may include new
therapeutics, diagnostic tests, or even software programs. In such
cases, no part of the revenue generated from their development or sale
will be shared.</td>
<td>Some of the research done with the information stored in the
databases may one day lead to the development of software, tests, drugs,
or other commercial products. If this happens, you will not receive any
of the profits.</td>
</tr>
<tr class="odd">
<td><strong>Data withdrawal</strong></td>
<td>Not possible to withdraw data that has already been shared</td>
<td><p>The choice to participate is always yours. You may withdraw from
the study at any time. If you withdraw, no additional data will be
collected from you. We will continue to use any data already collected
unless you tell us otherwise.</p>
<p>Once data have been de-identified and shared via CONP, they cannot be
deleted. Your privacy is important to us, and your data will continue to
benefit from the privacy protections we use for all
participants.</p></td>
<td><p>You are free to withdraw from the project at any stage. If you
withdraw before testing and data is collected, we will not continue. If
you withdraw after testing and data is collected, we will use any
information already collected unless you tell us not to. However, if
your data has already been shared it may not be possible to retrieve or
remove all your data.</p>
<p>You can withdraw your data at any time by contacting [<em>name of
relevant person</em>] free of charge at [<em>information</em>]. Data
sent to other researchers around the world cannot be withdrawn if
already used or published.</p></td>
</tr>
<tr class="even">
<td><strong>Re-identification</strong></td>
<td>Low risk that the participant could be re-identified in the
future</td>
<td>Your privacy will be protected through advanced de-identification
techniques. Despite this, this is always a small risk that your shared
data may one day enable someone to identify you. For example, someone
could use information in your clinical record to match you in a dataset.
This is difficult to do because of the de-identification measures.
Extensive sharing of personal information through social media or
genealogical websites may also make it easier to re-identify you. With
technological advances, however, it may become less difficult. Unable to
foresee such advances, we use today’s best protections. In the remote
chance that you are re-identified, you or your relatives may suffer a
loss of privacy or potentially be subject to discrimination</td>
<td><p>Some participants worry about being identified as someone taking
part in the project. The chance of this happening is extremely small
[<em>consider including an estimation of such risk, such as “i.e., less
than 1%”</em>], and we will do everything we can to prevent this from
happening.</p>
<p>Much like fingerprints, it is possible to identify someone if certain
pieces of information are put together. While we use very strict data
security measures to protect your privacy, there is always a small risk
that your data may lead to you being re-identified. As technology
advances, there may be new ways of linking data back to you that we
cannot foresee today. Like other medical information, this may one day
affect your insurability or your employment.</p></td>
</tr>
</tbody>
</table>

1.  Modified from the [<u>Global Alliance for Genomics and Health’s
    model consent
    clauses</u>](https://drive.google.com/file/d/1O5Ti7g7QJqS3h0ABm-LyTe02Gtq8wlKM).
